function [x,xtest]=changesign(trainmodel,xtest)
% A function which normalizes X and changes the signs based on the c-index
% of the training data
%
% >> [x,xtest]=changesign(trainmodel,xtest)
%
% Input
% 'trainmodel' is structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'xtest' is testing input data: a matrix n colums and d rows
%
% Output
% 'x' is the normalized and changed training input data of training set
% 'xtest' is the normalized and changed testing input data of test set
%
% Author: Liu,Yang (liu.yang@it.uu.se)

% Preprocess
[~,x,y,delta]=ungroup(trainmodel);
d=size(x,2);

[x, xtest]=standardise(x, xtest, 1:d);

ci=zeros(d,1);
for i=1:d
    ci(i)=cindex(x(:,i),y,delta);
end

x(:,ci<.5)=-x(:,ci<.5);
xtest(:,ci<.5)=-xtest(:,ci<.5);

x      = [x ones(size(x,1),1)]; % add constant term
xtest  = [xtest ones(size(xtest,1),1)]; % add constant term