function bestgam = linesearch(model,par,method,methodpar)
% A search function to linear search the best parameter
%
% >> bestgam = linesearch(model,par,method,methodpar)
%
% Input
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'par' is the parameters setting of linesearch ({left,right,interval length,threshold})
% 'method' is a string of the name of the test testmethod we use ('CV','CV2')
% 'methodpar' is the parameters setting of the test testmethod ({K})
%
% Output
% 'bestgam' the best gam parameter: is a scalar
%
% Author: Liu,Yang (liu.yang@it.uu.se)

% Preprocess
[l,r,s,threshold]=par{:};
len=r-l;
d=ceil(1/s);%floor(sqrt(len))

% Loop until the s is small enough (small than the threshold)
k=0;
while s>threshold
    k=k+1;
    %C = progress('init',['Determine initial tuning parameters...',': # searching cycle(s) ', num2str(k)]);
    % Set index and gams
    index=l:s:r;
    
    % init c
    c=zeros(length(index),1);
    
    for j=1 :length(index)
        model.gam=exp(index(j));
        c(j)=feval(method,model,methodpar{:});
        %C = progress(C,j/length(index));
    end
    
    [bestc,i]=max(c);
    
    % Update the left and right boundary
    l=index(i)-d*s;
    r=index(i)+d*s;
    
    s=(r-l)/len;
    %figure;
    %plot(index,c);
    %clear c;
end

% return best gammar
bestgam=exp(index(i));

