function bestgam = linesearch2(model,par,method,methodpar)
% A search function to linear search the best parameter
%
% >> bestgam = linesearch(model,par,method,methodpar)
%
% Input
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'par' is the parameters setting of linesearch ({left,right,interval length,threshold})
% 'method' is a string of the name of the test testmethod we use ('CV','CV2')
% 'methodpar' is the parameters setting of the test testmethod ({K})
%
% Output
% 'bestgam' the best gam parameter: is a scalar
%
% Author: Liu,Yang (liu.yang@it.uu.se)

% Preprocess
[l,r,s,threshold]=par{:};

% Set index and gams
index=l:s:r;

% init c
c=zeros(length(index),1);

for j=1 :length(index)
    model.gam=exp(index(j));
    c(j)=feval(method,model,methodpar{:});
end

[bestc,i]=max(c);
c(i)=-Inf;
[bestc2,i2]=max(c);
C=index(i);

% Update the left and right boundary
l=index(i)-2*s/3;
r=index(i)+2*s/3;
l2=index(i2)-2*s/3;
r2=index(i2)+2*s/3;

range=[l:s/3:r,l2:s/3:r2];
range([3,8])=[];
if i2==i+1 range=l:s/3:r2; range([3,6])=[]; end
if i2==i-1 range=l2:s/3:r; range([3,6])=[]; end

for j=1 :length(range)
    model.gam=exp(renge(j));
    c(j)=feval(method,model,methodpar{:});
end

[bestcc,ii]=max(c);
if bestcc>bestc
    C=range(ii);
end

% return best gammar
bestgam=exp(C);

