function [func,X,Y,delta,gam,mu]=ungroup(model)
% A function ungroup the model and assign the values to different variables
%
% >> [func,X,Y,delta]=ungroup(model)
% >> [func,X,Y,delta,gam]=ungroup(model)
% >> [func,X,Y,delta,gam,mu]=ungroup(model)
%
% Input:
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'

% Output:
% 'func' the name of the model function: is a string
% 'X' input: is a matrix of n x d
% 'Y' time: is a vector of n elements
% 'delta' censoring: is a vector of n elements (0-1 values, 0 means events and 1 means censored)
% 'gam' a parameter: is a scalar
% 'mu' a parameter: is a scalar
%
% Author: Liu,Yang (liu.yang@it.uu.se)

func=model.func;
X=model.X;
Y=model.Y;
delta=model.delta;
if nargout>4
    if isfield(model,'gam')
        gam=model.gam;
    else
        gam=0;
    end
end
if nargout>5
    if isfield(model,'mu')
        mu=model.mu;
    else
        mu=0;
    end
end